@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import compileall
 import contextlib
 import fnmatch
@@ -8,26 +10,14 @@ import shutil
 import subprocess
 import sys
 import threading
+from collections.abc import Iterable, Iterator
+from contextlib import AbstractContextManager
 from dataclasses import dataclass
 from enum import Enum
 from hashlib import sha256
 from pathlib import Path
 from textwrap import dedent
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    AnyStr,
-    Callable,
-    ClassVar,
-    ContextManager,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Set,
-    Tuple,
-)
+from typing import TYPE_CHECKING, Any, AnyStr, Callable, ClassVar
 from unittest.mock import patch
 from zipfile import ZipFile
 
@@ -57,11 +47,11 @@ from tests.lib import (
     ScriptFactory,
     TestData,
 )
-from tests.lib.server import MockServer, make_mock_server
+from tests.lib.server import MockServer, make_mock_server, patch_getfqdn
 from tests.lib.venv import VirtualEnvironment, VirtualEnvironmentType
 
 if TYPE_CHECKING:
-    from pip._vendor.typing_extensions import Self
+    from typing_extensions import Self
 
 
 def pytest_addoption(parser: Parser) -> None:
@@ -104,7 +94,7 @@ def pytest_addoption(parser: Parser) -> None:
     )
 
 
-def pytest_collection_modifyitems(config: Config, items: List[pytest.Function]) -> None:
+def pytest_collection_modifyitems(config: Config, items: list[pytest.Function]) -> None:
     for item in items:
         if not hasattr(item, "module"):  # e.g.: DoctestTextfile
             continue
@@ -112,6 +102,10 @@ def pytest_collection_modifyitems(config: Config, items: List[pytest.Function])
         if item.get_closest_marker("search") and not config.getoption("--run-search"):
             item.add_marker(pytest.mark.skip("pip search test skipped"))
 
+        # Exempt tests known to use the network from pytest-subket.
+        if item.get_closest_marker("network") is not None:
+            item.add_marker(pytest.mark.enable_socket)
+
         if "CI" in os.environ:
             # Mark network tests as flaky
             if item.get_closest_marker("network") is not None:
@@ -132,11 +126,7 @@ def pytest_collection_modifyitems(config: Config, items: List[pytest.Function])
         )
 
         module_root_dir = module_path.split(os.pathsep)[0]
-        if (
-            module_root_dir.startswith("functional")
-            or module_root_dir.startswith("integration")
-            or module_root_dir.startswith("lib")
-        ):
+        if module_root_dir.startswith(("functional", "integration", "lib")):
             item.add_marker(pytest.mark.integration)
         elif module_root_dir.startswith("unit"):
             item.add_marker(pytest.mark.unit)
@@ -337,7 +327,7 @@ def scoped_global_tempdir_manager(request: pytest.FixtureRequest) -> Iterator[No
     temporary directories in the application.
     """
     if "no_auto_tempdir_manager" in request.keywords:
-        ctx: Callable[[], ContextManager[None]] = contextlib.nullcontext
+        ctx: Callable[[], AbstractContextManager[None]] = contextlib.nullcontext
     else:
         ctx = global_tempdir_manager
 
@@ -347,7 +337,7 @@ def scoped_global_tempdir_manager(request: pytest.FixtureRequest) -> Iterator[No
 
 @pytest.fixture(scope="session")
 def pip_src(tmpdir_factory: pytest.TempPathFactory) -> Path:
-    def not_code_files_and_folders(path: str, names: List[str]) -> Iterable[str]:
+    def not_code_files_and_folders(path: str, names: list[str]) -> Iterable[str]:
         # In the root directory...
         if os.path.samefile(path, SRC_DIR):
             # ignore all folders except "src"
@@ -380,7 +370,7 @@ def pip_src(tmpdir_factory: pytest.TempPathFactory) -> Path:
 @pytest.fixture(scope="session")
 def pip_editable_parts(
     pip_src: Path, tmpdir_factory: pytest.TempPathFactory
-) -> Tuple[Path, ...]:
+) -> tuple[Path, ...]:
     pip_editable = tmpdir_factory.mktemp("pip") / "pip"
     shutil.copytree(pip_src, pip_editable, symlinks=True)
     # noxfile.py is Python 3 only
@@ -430,6 +420,7 @@ def _common_wheel_editable_install(
                 },
                 interpreter=sys.executable,
                 script_kind="posix",
+                bytecode_optimization_levels=[0],
             ),
             additional_metadata={},
         )
@@ -449,11 +440,6 @@ def setuptools_install(
     return _common_wheel_editable_install(tmpdir_factory, common_wheels, "setuptools")
 
 
-@pytest.fixture(scope="session")
-def wheel_install(tmpdir_factory: pytest.TempPathFactory, common_wheels: Path) -> Path:
-    return _common_wheel_editable_install(tmpdir_factory, common_wheels, "wheel")
-
-
 @pytest.fixture(scope="session")
 def coverage_install(
     tmpdir_factory: pytest.TempPathFactory, common_wheels: Path
@@ -461,6 +447,18 @@ def coverage_install(
     return _common_wheel_editable_install(tmpdir_factory, common_wheels, "coverage")
 
 
+@pytest.fixture(scope="session")
+def socket_install(tmpdir_factory: pytest.TempPathFactory, common_wheels: Path) -> Path:
+    lib_dir = _common_wheel_editable_install(
+        tmpdir_factory, common_wheels, "pytest_subket"
+    )
+    # pytest-subket is only included so it can intercept and block unexpected
+    # network requests. It should NOT be visible to the pip under test.
+    dist_info = next(lib_dir.glob("*.dist-info"))
+    shutil.rmtree(dist_info)
+    return lib_dir
+
+
 def install_pth_link(
     venv: VirtualEnvironment, project_name: str, lib_dir: Path
 ) -> None:
@@ -474,10 +472,10 @@ def virtualenv_template(
     request: pytest.FixtureRequest,
     tmpdir_factory: pytest.TempPathFactory,
     pip_src: Path,
-    pip_editable_parts: Tuple[Path, ...],
+    pip_editable_parts: tuple[Path, ...],
     setuptools_install: Path,
-    wheel_install: Path,
     coverage_install: Path,
+    socket_install: Path,
 ) -> VirtualEnvironment:
     venv_type: VirtualEnvironmentType
     if request.config.getoption("--use-venv"):
@@ -489,9 +487,12 @@ def virtualenv_template(
     tmpdir = tmpdir_factory.mktemp("virtualenv")
     venv = VirtualEnvironment(tmpdir.joinpath("venv_orig"), venv_type=venv_type)
 
-    # Install setuptools, wheel and pip.
+    # Install setuptools, pytest-subket, and pip.
     install_pth_link(venv, "setuptools", setuptools_install)
-    install_pth_link(venv, "wheel", wheel_install)
+    install_pth_link(venv, "pytest_subket", socket_install)
+    # Also copy pytest-subket's .pth file so it can intercept socket calls.
+    with open(venv.site / "pytest_socket.pth", "w") as f:
+        f.write(socket_install.joinpath("pytest_socket.pth").read_text())
 
     pth, dist_info = pip_editable_parts
 
@@ -504,19 +505,17 @@ def virtualenv_template(
     # detects changed files.
     venv.site.joinpath("easy-install.pth").touch()
 
-    # Install coverage and pth file for executing it in any spawned processes
-    # in this virtual environment.
-    install_pth_link(venv, "coverage", coverage_install)
-    # zz prefix ensures the file is after easy-install.pth.
-    with open(venv.site / "zz-coverage-helper.pth", "a") as f:
-        f.write("import coverage; coverage.process_startup()")
+    if request.config.getoption("--cov"):
+        # Install coverage and pth file for executing it in any spawned processes
+        # in this virtual environment.
+        install_pth_link(venv, "coverage", coverage_install)
+        # zz prefix ensures the file is after easy-install.pth.
+        with open(venv.site / "zz-coverage-helper.pth", "a") as f:
+            f.write("import coverage; coverage.process_startup()")
 
     # Drop (non-relocatable) launchers.
     for exe in os.listdir(venv.bin):
-        if not (
-            exe.startswith("python")
-            or exe.startswith("libpy")  # Don't remove libpypy-c.so...
-        ):
+        if not exe.startswith(("python", "libpy")):  # Don't remove libpypy-c.so...
             (venv.bin / exe).unlink()
 
     # Rename original virtualenv directory to make sure
@@ -553,12 +552,12 @@ def virtualenv(
 def script_factory(
     virtualenv_factory: Callable[[Path], VirtualEnvironment],
     deprecated_python: bool,
-    zipapp: Optional[str],
+    zipapp: str | None,
 ) -> ScriptFactory:
     def factory(
         tmpdir: Path,
-        virtualenv: Optional[VirtualEnvironment] = None,
-        environ: Optional[Dict[AnyStr, AnyStr]] = None,
+        virtualenv: VirtualEnvironment | None = None,
+        environ: dict[AnyStr, AnyStr] | None = None,
     ) -> PipTestEnvironment:
         kwargs = {}
         if environ:
@@ -620,7 +619,7 @@ def make_zipapp_from_pip(zipapp_name: Path) -> None:
 @pytest.fixture(scope="session")
 def zipapp(
     request: pytest.FixtureRequest, tmpdir_factory: pytest.TempPathFactory
-) -> Optional[str]:
+) -> str | None:
     """
     If the user requested for pip to be run from a zipapp, build that zipapp
     and return its location. If the user didn't request a zipapp, return None.
@@ -746,9 +745,9 @@ class FakePackage:
     filename: str
     metadata: MetadataKind
     # This will override any dependencies specified in the actual dist's METADATA.
-    requires_dist: Tuple[str, ...] = ()
+    requires_dist: tuple[str, ...] = ()
     # This will override the Name specified in the actual dist's METADATA.
-    metadata_name: Optional[str] = None
+    metadata_name: str | None = None
 
     def metadata_filename(self) -> str:
         """This is specified by PEP 658."""
@@ -787,7 +786,7 @@ class FakePackage:
 
 
 @pytest.fixture(scope="session")
-def fake_packages() -> Dict[str, List[FakePackage]]:
+def fake_packages() -> dict[str, list[FakePackage]]:
     """The package database we generate for testing PEP 658 support."""
     return {
         "simple": [
@@ -880,7 +879,7 @@ def fake_packages() -> Dict[str, List[FakePackage]]:
 @pytest.fixture(scope="session")
 def html_index_for_packages(
     shared_data: TestData,
-    fake_packages: Dict[str, List[FakePackage]],
+    fake_packages: dict[str, list[FakePackage]],
     tmpdir_factory: pytest.TempPathFactory,
 ) -> Path:
     """Generate a PyPI HTML package index within a local directory pointing to
@@ -915,7 +914,7 @@ def html_index_for_packages(
         pkg_subdir = html_dir / pkg
         pkg_subdir.mkdir()
 
-        download_links: List[str] = []
+        download_links: list[str] = []
         for package_link in links:
             # (3.1) Generate the <a> tag which pip can crawl pointing to this
             # specific package version.
@@ -960,7 +959,7 @@ class OneTimeDownloadHandler(http.server.SimpleHTTPRequestHandler):
     """Serve files from the current directory, but error if a file is downloaded more
     than once."""
 
-    _seen_paths: ClassVar[Set[str]] = set()
+    _seen_paths: ClassVar[set[str]] = set()
 
     def do_GET(self) -> None:
         if self.path in self._seen_paths:
@@ -985,7 +984,7 @@ def html_index_with_onetime_server(
     """
 
     class InDirectoryServer(http.server.ThreadingHTTPServer):
-        def finish_request(self: "Self", request: Any, client_address: Any) -> None:
+        def finish_request(self: Self, request: Any, client_address: Any) -> None:
             self.RequestHandlerClass(
                 request,
                 client_address,
@@ -994,9 +993,9 @@ def html_index_with_onetime_server(
             )
 
     class Handler(OneTimeDownloadHandler):
-        _seen_paths: ClassVar[Set[str]] = set()
+        _seen_paths: ClassVar[set[str]] = set()
 
-    with InDirectoryServer(("", 8000), Handler) as httpd:
+    with patch_getfqdn(), InDirectoryServer(("", 8000), Handler) as httpd:
         server_thread = threading.Thread(target=httpd.serve_forever)
         server_thread.start()
 
