@@ -5,18 +5,18 @@ import shutil
 import textwrap
 from hashlib import sha256
 from pathlib import Path
-from typing import Callable, List, Tuple
+from typing import Callable
 
 import pytest
 
 from pip._internal.cli.status_codes import ERROR
 from pip._internal.utils.urls import path_to_url
+
 from tests.lib import (
     PipTestEnvironment,
     ScriptFactory,
     TestData,
     TestPipResult,
-    create_basic_sdist_for_package,
     create_really_basic_wheel,
 )
 from tests.lib.server import MockServer, file_response
@@ -29,22 +29,31 @@ def fake_wheel(data: TestData, wheel_path: str) -> None:
     data.packages.joinpath(wheel_path).write_bytes(wheel_data)
 
 
-@pytest.mark.network
-def test_download_if_requested(script: PipTestEnvironment) -> None:
+def test_download_if_requested(script: PipTestEnvironment, data: TestData) -> None:
     """
     It should download (in the scratch path) and not install if requested.
     """
-    result = script.pip("download", "-d", "pip_downloads", "INITools==0.1")
+    result = script.pip(
+        "download",
+        "--no-index",
+        "-d",
+        "pip_downloads",
+        "INITools==0.1",
+        "-f",
+        data.pypi_packages,
+        "--no-build-isolation",
+    )
     result.did_create(Path("scratch") / "pip_downloads" / "INITools-0.1.tar.gz")
     result.did_not_create(script.site_packages / "initools")
 
 
-@pytest.mark.network
-def test_basic_download_setuptools(script: PipTestEnvironment) -> None:
+def test_basic_download_setuptools(script: PipTestEnvironment, data: TestData) -> None:
     """
     It should download (in the scratch path) and not install if requested.
     """
-    result = script.pip("download", "setuptools")
+    result = script.pip(
+        "download", "setuptools", "--no-index", "-f", data.common_wheels
+    )
     setuptools_prefix = str(Path("scratch") / "setuptools")
     assert any(os.fspath(p).startswith(setuptools_prefix) for p in result.files_created)
 
@@ -53,32 +62,39 @@ def test_download_wheel(script: PipTestEnvironment, data: TestData) -> None:
     """
     Test using "pip download" to download a *.whl archive.
     """
+    # This test needs --no-build-isolation because `meta` depends on `simple`
+    # which is a source distribution for which it needs to prepare metadata
+    # to look for transitive dependencies.
     result = script.pip(
-        "download", "--no-index", "-f", data.packages, "-d", ".", "meta"
+        "download",
+        "--no-build-isolation",
+        "--no-index",
+        "-f",
+        data.packages,
+        "-d",
+        ".",
+        "meta",
     )
     result.did_create(Path("scratch") / "meta-1.0-py2.py3-none-any.whl")
     result.did_not_create(script.site_packages / "piptestpackage")
 
 
-@pytest.mark.network
-def test_single_download_from_requirements_file(script: PipTestEnvironment) -> None:
+def test_single_download_from_requirements_file(
+    script: PipTestEnvironment, data: TestData
+) -> None:
     """
-    It should support download (in the scratch path) from PyPI from a
+    It should support download (in the scratch path) from a
     requirements file
     """
-    script.scratch_path.joinpath("test-req.txt").write_text(
-        textwrap.dedent(
-            """
-        INITools==0.1
-        """
-        )
-    )
+    req_file = script.temporary_file("test-req.txt", "INITools==0.1")
     result = script.pip(
         "download",
         "-r",
-        script.scratch_path / "test-req.txt",
-        "-d",
-        ".",
+        req_file,
+        "--no-index",
+        "-f",
+        data.pypi_packages,
+        "--no-build-isolation",
     )
     result.did_create(Path("scratch") / "INITools-0.1.tar.gz")
     result.did_not_create(script.site_packages / "initools")
@@ -121,61 +137,42 @@ def test_download_should_download_wheel_deps(
     dep_filename = "translationstring-1.1.tar.gz"
     wheel_path = "/".join((data.find_links, wheel_filename))
     result = script.pip(
-        "download", wheel_path, "-d", ".", "--find-links", data.find_links, "--no-index"
+        "download",
+        "--no-build-isolation",
+        wheel_path,
+        "-d",
+        ".",
+        "--find-links",
+        data.find_links,
+        "--no-index",
     )
     result.did_create(Path("scratch") / wheel_filename)
     result.did_create(Path("scratch") / dep_filename)
 
 
-@pytest.mark.network
-def test_download_should_skip_existing_files(script: PipTestEnvironment) -> None:
+def test_download_should_skip_existing_files(
+    script: PipTestEnvironment, data: TestData
+) -> None:
     """
     It should not download files already existing in the scratch dir
     """
-    script.scratch_path.joinpath("test-req.txt").write_text(
-        textwrap.dedent(
-            """
-        INITools==0.1
-        """
-        )
-    )
-
-    result = script.pip(
-        "download",
-        "-r",
-        script.scratch_path / "test-req.txt",
-        "-d",
-        ".",
-    )
-    result.did_create(Path("scratch") / "INITools-0.1.tar.gz")
-    result.did_not_create(script.site_packages / "initools")
+    req_file = script.temporary_file("reqs.txt", "simplewheel==1.0")
+    result = script.pip("download", "-r", req_file, "-f", data.packages, "--no-index")
+    result.did_create(Path("scratch") / "simplewheel-1.0-py2.py3-none-any.whl")
+    result.did_not_create(script.site_packages / "simplewheel")
 
     # adding second package to test-req.txt
-    script.scratch_path.joinpath("test-req.txt").write_text(
-        textwrap.dedent(
-            """
-        INITools==0.1
-        python-openid==2.2.5
-        """
-        )
-    )
+    script.temporary_file(req_file, "simplewheel==1.0\nsimple.dist")
 
     # only the second package should be downloaded
-    result = script.pip(
-        "download",
-        "-r",
-        script.scratch_path / "test-req.txt",
-        "-d",
-        ".",
-    )
-    openid_tarball_prefix = str(Path("scratch") / "python-openid-")
+    result = script.pip("download", "-r", req_file, "-f", data.packages, "--no-index")
     assert any(
-        os.fspath(path).startswith(openid_tarball_prefix)
+        os.fspath(path).startswith(str(Path("scratch") / "simple.dist"))
         for path in result.files_created
     )
-    result.did_not_create(Path("scratch") / "INITools-0.1.tar.gz")
-    result.did_not_create(script.site_packages / "initools")
-    result.did_not_create(script.site_packages / "openid")
+    result.did_not_create(Path("scratch") / "simplewheel-1.0-py2.py3-none-any.whl")
+    result.did_not_create(script.site_packages / "simplewheel")
+    result.did_not_create(script.site_packages / "simpledist")
 
 
 @pytest.mark.network
@@ -669,7 +666,7 @@ def test_download__python_version_used_for_python_requires(
     )
     wheel_dir = os.path.dirname(wheel_path)
 
-    def make_args(python_version: str) -> List[str]:
+    def make_args(python_version: str) -> list[str]:
         return [
             "download",
             "--no-index",
@@ -686,8 +683,7 @@ def test_download__python_version_used_for_python_requires(
     args = make_args("33")
     result = script.pip(*args, expect_error=True)
     expected_err = (
-        "ERROR: Package 'mypackage' requires a different Python: "
-        "3.3.0 not in '==3.2'"
+        "ERROR: Package 'mypackage' requires a different Python: 3.3.0 not in '==3.2'"
     )
     assert expected_err in result.stderr, f"stderr: {result.stderr}"
 
@@ -977,6 +973,7 @@ def test_download_prefer_binary_when_wheel_doesnt_satisfy_req(
 
     result = script.pip(
         "download",
+        "--no-build-isolation",
         "--prefer-binary",
         "--no-index",
         "-f",
@@ -1005,6 +1002,7 @@ def test_prefer_binary_when_wheel_doesnt_satisfy_req_req_file(
 
     result = script.pip(
         "download",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.packages,
@@ -1022,6 +1020,7 @@ def test_download_prefer_binary_when_only_tarball_exists(
 ) -> None:
     result = script.pip(
         "download",
+        "--no-build-isolation",
         "--prefer-binary",
         "--no-index",
         "-f",
@@ -1046,6 +1045,7 @@ def test_prefer_binary_when_only_tarball_exists_req_file(
     )
     result = script.pip(
         "download",
+        "--no-build-isolation",
         "--no-index",
         "-f",
         data.packages,
@@ -1077,6 +1077,7 @@ def test_download_file_url(
 
     shared_script.pip(
         "download",
+        "--no-build-isolation",
         "-d",
         str(download_dir),
         "--no-index",
@@ -1100,7 +1101,14 @@ def test_download_file_url_existing_ok_download(
     simple_pkg = shared_data.packages / "simple-1.0.tar.gz"
     url = f"{simple_pkg.as_uri()}#sha256={sha256(downloaded_path_bytes).hexdigest()}"
 
-    shared_script.pip("download", "-d", str(download_dir), url)
+    shared_script.pip(
+        "download",
+        "--no-build-isolation",
+        "-d",
+        str(download_dir),
+        url,
+        "--disable-pip-version-check",
+    )
 
     assert downloaded_path_bytes == downloaded_path.read_bytes()
 
@@ -1120,6 +1128,7 @@ def test_download_file_url_existing_bad_download(
 
     result = shared_script.pip(
         "download",
+        "--no-build-isolation",
         "-d",
         str(download_dir),
         url,
@@ -1156,6 +1165,7 @@ def test_download_http_url_bad_hash(
 
     result = shared_script.pip(
         "download",
+        "--no-build-isolation",
         "-d",
         str(download_dir),
         url,
@@ -1184,75 +1194,39 @@ def test_download_editable(
     requirements_path.write_text("-e " + editable_path + "\n")
     download_dir = tmpdir / "download_dir"
     script.pip(
-        "download", "--no-deps", "-r", str(requirements_path), "-d", str(download_dir)
+        "download",
+        "--no-build-isolation",
+        "--no-deps",
+        "-r",
+        str(requirements_path),
+        "-d",
+        str(download_dir),
     )
     downloads = os.listdir(download_dir)
     assert len(downloads) == 1
     assert downloads[0].endswith(".zip")
 
 
-def test_download_use_pep517_propagation(
-    script: PipTestEnvironment, tmpdir: Path, common_wheels: Path
-) -> None:
-    """
-    Check that --use-pep517 applies not just to the requirements specified
-    on the command line, but to their dependencies too.
-    """
-
-    create_basic_sdist_for_package(script, "fake_proj", "1.0", depends=["fake_dep"])
-
-    # If --use-pep517 is in effect, then setup.py should be running in an isolated
-    # environment that doesn't have pip in it.
-    create_basic_sdist_for_package(
-        script,
-        "fake_dep",
-        "1.0",
-        setup_py_prelude=textwrap.dedent(
-            """\
-            try:
-                import pip
-            except ImportError:
-                pass
-            else:
-                raise Exception(f"not running in isolation")
-            """
-        ),
-    )
-
-    download_dir = tmpdir / "download_dir"
-    script.pip(
-        "download",
-        f"--dest={download_dir}",
-        "--no-index",
-        f"--find-links={common_wheels}",
-        f"--find-links={script.scratch_path}",
-        "--use-pep517",
-        "fake_proj",
-    )
-
-    downloads = os.listdir(download_dir)
-    assert len(downloads) == 2
-
-
-@pytest.fixture(scope="function")
+@pytest.fixture
 def download_local_html_index(
     script: PipTestEnvironment,
     html_index_for_packages: Path,
     tmpdir: Path,
-) -> Callable[..., Tuple[TestPipResult, Path]]:
+) -> Callable[..., tuple[TestPipResult, Path]]:
     """Execute `pip download` against a generated PyPI index."""
     download_dir = tmpdir / "download_dir"
 
     def run_for_generated_index(
-        args: List[str],
+        args: list[str],
         allow_error: bool = False,
-    ) -> Tuple[TestPipResult, Path]:
+    ) -> tuple[TestPipResult, Path]:
         """
         Produce a PyPI directory structure pointing to the specified packages, then
         execute `pip download -i ...` pointing to our generated index.
         """
         pip_args = [
             "download",
+            "--no-build-isolation",
             "-d",
             str(download_dir),
             "-i",
@@ -1265,25 +1239,26 @@ def download_local_html_index(
     return run_for_generated_index
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def download_server_html_index(
     script: PipTestEnvironment,
     tmpdir: Path,
     html_index_with_onetime_server: http.server.ThreadingHTTPServer,
-) -> Callable[..., Tuple[TestPipResult, Path]]:
+) -> Callable[..., tuple[TestPipResult, Path]]:
     """Execute `pip download` against a generated PyPI index."""
     download_dir = tmpdir / "download_dir"
 
     def run_for_generated_index(
-        args: List[str],
+        args: list[str],
         allow_error: bool = False,
-    ) -> Tuple[TestPipResult, Path]:
+    ) -> tuple[TestPipResult, Path]:
         """
         Produce a PyPI directory structure pointing to the specified packages, then
         execute `pip download -i ...` pointing to our generated index.
         """
         pip_args = [
             "download",
+            "--no-build-isolation",
             "-d",
             str(download_dir),
             "-i",
@@ -1312,9 +1287,9 @@ def download_server_html_index(
     ],
 )
 def test_download_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
-    expected_outputs: List[str],
+    expected_outputs: list[str],
 ) -> None:
     """Verify that if a data-dist-info-metadata attribute is present, then it is used
     instead of the actual dist's METADATA."""
@@ -1349,9 +1324,9 @@ def test_download_metadata(
     ],
 )
 def test_download_metadata_server(
-    download_server_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_server_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
-    expected_outputs: List[str],
+    expected_outputs: list[str],
     doubled_path: str,
 ) -> None:
     """Verify that if a data-dist-info-metadata attribute is present, then it is used
@@ -1389,7 +1364,7 @@ def test_download_metadata_server(
     ],
 )
 def test_incorrect_metadata_hash(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
     real_hash: str,
 ) -> None:
@@ -1401,7 +1376,7 @@ def test_incorrect_metadata_hash(
     )
     assert result.returncode != 0
     expected_msg = f"""\
-        Expected sha256 WRONG-HASH
+        Expected sha256 wrong-hash
              Got        {real_hash}"""
     assert expected_msg in result.stderr
 
@@ -1414,7 +1389,7 @@ def test_incorrect_metadata_hash(
     ],
 )
 def test_metadata_not_found(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
     expected_url: str,
 ) -> None:
@@ -1434,7 +1409,7 @@ def test_metadata_not_found(
 
 
 def test_produces_error_for_mismatched_package_name_in_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
 ) -> None:
     """Verify that the package name from the metadata matches the requested package."""
     result, _ = download_local_html_index(
@@ -1450,14 +1425,14 @@ def test_produces_error_for_mismatched_package_name_in_metadata(
 
 @pytest.mark.parametrize(
     "requirement",
-    (
+    [
         "requires-simple-extra==0.1",
         "REQUIRES_SIMPLE-EXTRA==0.1",
         "REQUIRES....simple-_-EXTRA==0.1",
-    ),
+    ],
 )
 def test_canonicalizes_package_name_before_verifying_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement: str,
 ) -> None:
     """Verify that the package name from the command line and the package's
