@@ -1,12 +1,15 @@
+from __future__ import annotations
+
 import contextlib
 import email.message
 import os
 import shutil
 import sys
 import tempfile
+from collections.abc import Iterator
 from functools import partial
 from pathlib import Path
-from typing import Iterator, Optional, Set, Tuple, cast
+from typing import cast
 from unittest import mock
 
 import pytest
@@ -14,6 +17,7 @@ import pytest
 from pip._vendor.packaging.markers import Marker
 from pip._vendor.packaging.requirements import Requirement
 
+from pip._internal.build_env import SubprocessBuildEnvironmentInstaller
 from pip._internal.cache import WheelCache
 from pip._internal.commands import create_command
 from pip._internal.commands.install import InstallCommand
@@ -47,6 +51,7 @@ from pip._internal.req.req_file import (
     handle_requirement_line,
 )
 from pip._internal.resolution.legacy.resolver import Resolver
+from pip._internal.utils.urls import path_to_url
 
 from tests.lib import TestData, make_test_finder, requirements_file, wheel
 
@@ -84,21 +89,23 @@ class TestRequirementSet:
         self,
         finder: PackageFinder,
         require_hashes: bool = False,
-        wheel_cache: Optional[WheelCache] = None,
+        wheel_cache: WheelCache | None = None,
+        build_isolation: bool = True,
     ) -> Iterator[Resolver]:
         make_install_req = partial(
             install_req_from_req_string,
             isolated=False,
-            use_pep517=None,
         )
         session = PipSession()
 
         with get_build_tracker() as tracker:
+            installer = SubprocessBuildEnvironmentInstaller(finder)
             preparer = RequirementPreparer(
                 build_dir=os.path.join(self.tempdir, "build"),
                 src_dir=os.path.join(self.tempdir, "src"),
                 download_dir=None,
-                build_isolation=True,
+                build_isolation=build_isolation,
+                build_isolation_installer=installer,
                 check_build_deps=False,
                 build_tracker=tracker,
                 session=session,
@@ -109,7 +116,6 @@ class TestRequirementSet:
                 lazy_wheel=False,
                 verbosity=0,
                 legacy_resolver=True,
-                resume_retries=0,
             )
             yield Resolver(
                 preparer=preparer,
@@ -159,7 +165,7 @@ class TestRequirementSet:
         req.user_supplied = True
         reqset.add_unnamed_requirement(req)
         finder = make_test_finder(find_links=[data.find_links])
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             reqset = resolver.resolve(reqset.all_requirements, True)
         assert not reqset.has_requirement("simple")
 
@@ -218,16 +224,12 @@ class TestRequirementSet:
         dir_path = data.packages.joinpath("FSPkg")
         reqset.add_unnamed_requirement(
             get_processed_req_from_line(
-                f"file://{dir_path}",
+                path_to_url(str(dir_path)),
                 lineno=2,
             )
         )
         finder = make_test_finder(find_links=[data.find_links])
 
-        sep = os.path.sep
-        if sep == "\\":
-            sep = "\\\\"  # This needs to be escaped for the regex
-
         with self._basic_resolver(finder, require_hashes=True) as resolver:
             with pytest.raises(
                 HashErrors,
@@ -238,7 +240,7 @@ class TestRequirementSet:
                     r"file \(line 1\)\)\n"
                     r"Can't verify hashes for these file:// requirements because "
                     r"they point to directories:\n"
-                    rf"    file://.*{sep}data{sep}packages{sep}FSPkg "
+                    r"    file://.*/data/packages/FSPkg "
                     r"\(from -r file \(line 2\)\)"
                 ),
             ):
@@ -316,7 +318,9 @@ class TestRequirementSet:
             )
         )
 
-        with self._basic_resolver(finder, require_hashes=True) as resolver:
+        with self._basic_resolver(
+            finder, require_hashes=True, build_isolation=False
+        ) as resolver:
             with pytest.raises(
                 HashErrors,
                 match=(
@@ -357,7 +361,7 @@ class TestRequirementSet:
     def test_download_info_find_links(self, data: TestData) -> None:
         """Test that download_info is set for requirements via find_links."""
         finder = make_test_finder(find_links=[data.find_links])
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             ireq = get_processed_req_from_line("simple")
             reqset = resolver.resolve([ireq], True)
             assert len(reqset.all_requirements) == 1
@@ -382,7 +386,7 @@ class TestRequirementSet:
     def test_download_info_web_archive(self) -> None:
         """Test that download_info is set for requirements from a web archive."""
         finder = make_test_finder()
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             ireq = get_processed_req_from_line(
                 "pip-test-package @ "
                 "https://github.com/pypa/pip-test-package/tarball/0.1.1"
@@ -492,7 +496,7 @@ class TestRequirementSet:
     def test_download_info_local_dir(self, data: TestData) -> None:
         """Test that download_info is set for requirements from a local dir."""
         finder = make_test_finder()
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             ireq_url = data.packages.joinpath("FSPkg").as_uri()
             ireq = get_processed_req_from_line(f"FSPkg @ {ireq_url}")
             reqset = resolver.resolve([ireq], True)
@@ -505,7 +509,7 @@ class TestRequirementSet:
     def test_download_info_local_editable_dir(self, data: TestData) -> None:
         """Test that download_info is set for requirements from a local editable dir."""
         finder = make_test_finder()
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             ireq_url = data.packages.joinpath("FSPkg").as_uri()
             ireq = get_processed_req_from_line(f"-e {ireq_url}#egg=FSPkg")
             reqset = resolver.resolve([ireq], True)
@@ -520,7 +524,7 @@ class TestRequirementSet:
     def test_download_info_vcs(self) -> None:
         """Test that download_info is set for requirements from git."""
         finder = make_test_finder()
-        with self._basic_resolver(finder) as resolver:
+        with self._basic_resolver(finder, build_isolation=False) as resolver:
             ireq = get_processed_req_from_line(
                 "pip-test-package @ git+https://github.com/pypa/pip-test-package"
             )
@@ -697,7 +701,7 @@ class TestInstallRequirement:
         assert req.extras == {"ex1", "ex2"}
 
     def test_extras_for_line_url_requirement(self) -> None:
-        line = "git+https://url#egg=SomeProject[ex1,ex2]"
+        line = "SomeProject[ex1,ex2] @ git+https://url"
         filename = "filename"
         comes_from = f"-r {filename} (line 1)"
         req = install_req_from_line(line, comes_from=comes_from)
@@ -713,7 +717,7 @@ class TestInstallRequirement:
         assert req.extras == {"ex1", "ex2"}
 
     def test_extras_for_editable_url_requirement(self) -> None:
-        url = "git+https://url#egg=SomeProject[ex1,ex2]"
+        url = "SomeProject[ex1,ex2] @ git+https://url"
         filename = "filename"
         comes_from = f"-r {filename} (line 1)"
         req = install_req_from_editable(url, comes_from=comes_from)
@@ -761,10 +765,11 @@ class TestInstallRequirement:
             ("pkg ; python_version<='3.6'", "pkg"),
             ("pkg[ext]", "pkg"),
             ("pkg [ ext1, ext2 ]", "pkg"),
-            ("pkg [ ext1, ext2 ] @ https://example.com/", "pkg@ https://example.com/"),
+            ("pkg [ ext1, ext2 ] @ https://example.com/", "pkg @ https://example.com/"),
             ("pkg [ext] == 1.0; python_version<='3.6'", "pkg==1.0"),
             ("pkg-all.allowed_chars0 ~= 2.0", "pkg-all.allowed_chars0~=2.0"),
             ("pkg-all.allowed_chars0 [ext] ~= 2.0", "pkg-all.allowed_chars0~=2.0"),
+            ("simple-0.1-py2.py3-none-any.whl [ext]", "simple==0.1"),
         ],
     )
     def test_install_req_drop_extras(self, inp: str, out: str) -> None:
@@ -788,9 +793,7 @@ class TestInstallRequirement:
         # all else should be the same
         assert without_extras.link == req.link
         assert without_extras.markers == req.markers
-        assert without_extras.use_pep517 == req.use_pep517
         assert without_extras.isolated == req.isolated
-        assert without_extras.global_options == req.global_options
         assert without_extras.hash_options == req.hash_options
         assert without_extras.constraint == req.constraint
         assert without_extras.config_settings == req.config_settings
@@ -811,12 +814,12 @@ class TestInstallRequirement:
             (
                 "pkg-all.allowed_chars0 [ ext1 ] @ https://example.com/",
                 {"ext2"},
-                "pkg-all.allowed_chars0[ext1,ext2]@ https://example.com/",
+                "pkg-all.allowed_chars0[ext1,ext2] @ https://example.com/",
             ),
         ],
     )
     def test_install_req_extend_extras(
-        self, inp: str, extras: Set[str], out: str
+        self, inp: str, extras: set[str], out: str
     ) -> None:
         """
         Test behavior of install_req_extend_extras
@@ -837,9 +840,7 @@ class TestInstallRequirement:
         # all else should be the same
         assert extended.link == req.link
         assert extended.markers == req.markers
-        assert extended.use_pep517 == req.use_pep517
         assert extended.isolated == req.isolated
-        assert extended.global_options == req.global_options
         assert extended.hash_options == req.hash_options
         assert extended.constraint == req.constraint
         assert extended.config_settings == req.config_settings
@@ -847,6 +848,25 @@ class TestInstallRequirement:
         assert extended.permit_editable_wheels == req.permit_editable_wheels
 
 
+@pytest.mark.parametrize(
+    "req_str, expected",
+    [
+        (
+            'foo[extra] @ svn+http://foo ; os_name == "nt"',
+            ('foo ; os_name == "nt"', "svn+http://foo", {"extra"}),
+        ),
+        (
+            "foo @ svn+http://foo",
+            ("foo", "svn+http://foo", set()),
+        ),
+    ],
+)
+def test_parse_editable_pep508(
+    req_str: str, expected: tuple[str, str, set[str]]
+) -> None:
+    assert parse_editable(req_str) == expected
+
+
 @mock.patch("pip._internal.req.req_install.os.path.abspath")
 @mock.patch("pip._internal.req.req_install.os.path.exists")
 @mock.patch("pip._internal.req.req_install.os.path.isdir")
@@ -874,10 +894,10 @@ def test_parse_editable_explicit_vcs() -> None:
 
 
 def test_parse_editable_vcs_extras() -> None:
-    assert parse_editable("svn+https://foo#egg=foo[extras]") == (
-        "foo[extras]",
-        "svn+https://foo#egg=foo[extras]",
-        set(),
+    assert parse_editable("foo[extras] @ svn+https://foo") == (
+        "foo",
+        "svn+https://foo",
+        {"extras"},
     )
 
 
@@ -997,8 +1017,8 @@ def test_looks_like_path_win(args: str, expected: bool) -> None:
 def test_get_url_from_path(
     isdir_mock: mock.Mock,
     isfile_mock: mock.Mock,
-    args: Tuple[str, str],
-    mock_returns: Tuple[bool, bool],
+    args: tuple[str, str],
+    mock_returns: tuple[bool, bool],
     expected: None,
 ) -> None:
     isdir_mock.return_value = mock_returns[0]
